translate.storage.po

Package translate :: Package storage :: Module po |
[hide private]
[frames] | no frames]

# Module po

source code

A class loader that will load C or Python implementations of the PO class depending on the USECPO variable.

Use the environment variable USECPO=2 (or 1) to choose the C implementation which uses Gettext's libgettextpo for high parsing speed. Otherise the local Python based parser is used (slower but very well tested).

Imports: logging, cdll, CFUNCTYPE, po_xerror_handler, names, xerror2_cb, gpo, tempfile, c_int, get_libgettextpo_version, po_error_handler, xerror_prototype, Structure, c_long, c_char_p, STRING, pypo, c_uint, sys, ctypes, xerror_handler, c_size_t, xerror2_prototype, POINTER, xerror_cb, os, po_message, basic_header, cpo, cStringIO, is_null, extractstr, pounit, po_unescape_map, extractpoline, quoteforpo, unquotefrompo, urllib, re, encodingToUse, escapeforpo, quote, textwrap, multistring, copy, data, wrapline, poparser, pofile, base, lsep, unescapehandler, po_escape_map, pocommon